@@ -12,22 +12,22 @@
 ### AUTHORS:  Mathieu Pigeon, Vincent Goulet <vincent.goulet@act.ulaval.ca>
 
 dpareto <- function (x, shape, scale, log = FALSE)
-    .External("do_dpq", "dpareto", x, shape, scale, log)
+    .External("actuar_do_dpq", "dpareto", x, shape, scale, log)
 
 ppareto <- function (q, shape, scale, lower.tail = TRUE, log.p = FALSE)
-    .External("do_dpq", "ppareto", q, shape, scale, lower.tail, log.p)
+    .External("actuar_do_dpq", "ppareto", q, shape, scale, lower.tail, log.p)
 
 qpareto <- function (p, shape, scale, lower.tail = TRUE, log.p = FALSE)
-    .External("do_dpq", "qpareto", p, shape, scale, lower.tail, log.p)
+    .External("actuar_do_dpq", "qpareto", p, shape, scale, lower.tail, log.p)
 
 rpareto <- function(n, shape, scale)
-    .External("do_random", "rpareto", n, shape, scale)
+    .External("actuar_do_random", "rpareto", n, shape, scale)
 
 mpareto <- function(order, shape, scale)
-     .External("do_dpq", "mpareto", order, shape, scale, FALSE)
+     .External("actuar_do_dpq", "mpareto", order, shape, scale, FALSE)
 
 levpareto <- function(limit, shape, scale, order = 1)
-     .External("do_dpq", "levpareto", limit, shape, scale, order, FALSE)
+     .External("actuar_do_dpq", "levpareto", limit, shape, scale, order, FALSE)
 
 ## Aliases
 dpareto2 <- dpareto
