@@ -44,7 +44,7 @@ double levexp(double limit, double scale, double order, int give_log)
 
     return R_pow(scale, order) * gammafn(tmp) *
         pgamma(u, tmp, 1.0, 1, 0) +
-        R_VG__0(limit, order) * exp(-u);
+        ACT_DLIM__0(limit, order) * exp(-u);
 }
 
 double mgfexp(double x, double scale, int give_log)
@@ -55,7 +55,7 @@ double mgfexp(double x, double scale, int give_log)
         return R_NaN;
 
     if (x == 0.0)
-        return R_D_exp(0.0);
+        return ACT_D_exp(0.0);
 
-    return R_D_exp(-log1p(-scale * x));
+    return ACT_D_exp(-log1p(-scale * x));
 }
