@@ -7,11 +7,11 @@
 #include "actuar.h"
 
 static const R_ExternalMethodDef ExternalEntries[] = {
-    {"do_random", (DL_FUNC) &do_random, -1},
-    {"do_dpq", (DL_FUNC) &do_dpq, -1},
-    {"do_dpqphtype", (DL_FUNC) &do_dpqphtype, -1},
-    {"do_hierarc", (DL_FUNC) &do_hierarc, -1},
-    {"do_panjer", (DL_FUNC) &do_panjer, -1},
+    {"actuar_do_random", (DL_FUNC) &actuar_do_random, -1},
+    {"actuar_do_dpq", (DL_FUNC) &actuar_do_dpq, -1},
+    {"actuar_do_dpqphtype", (DL_FUNC) &actuar_do_dpqphtype, -1},
+    {"actuar_do_hierarc", (DL_FUNC) &actuar_do_hierarc, -1},
+    {"actuar_do_panjer", (DL_FUNC) &actuar_do_panjer, -1},
     {NULL, NULL, 0}
 };
 
