@@ -30,7 +30,7 @@ double minvGauss(double order, double nu, double lambda, int give_log)
 
     for (i = 0; i < n; i++)
         z += R_pow_di(nu, n) * gammafn(n + i) *
-            R_pow_di(2 * lambda/nu, -i) /
+            R_pow_di(2.0 * lambda/nu, -i) /
             (gammafn(i + 1) * gammafn(n - i));
     return z;
 }
@@ -57,7 +57,7 @@ double levinvGauss(double limit, double nu, double lambda, double order,
     z = (limit - nu)/nu;
 
     return limit - nu * z * pnorm(z * tmp, 0.0, 1.0, 1, 0)
-        - nu * y * exp(2 * lambda/nu) * pnorm(-y * tmp, 0.0, 1.0, 1, 0);
+        - nu * y * exp(2.0 * lambda/nu) * pnorm(-y * tmp, 0.0, 1.0, 1, 0);
 }
 
 double mgfinvGauss(double x, double nu, double lambda, int give_log)
@@ -66,11 +66,11 @@ double mgfinvGauss(double x, double nu, double lambda, int give_log)
         !R_FINITE(lambda) ||
         nu <= 0.0 ||
         lambda < 0.0 ||
-        x > lambda/(2 * nu * nu))
+        x > lambda/(2.0 * nu * nu))
         return R_NaN;
 
     if (x == 0.0)
-        return R_D_exp(0.0);
+        return ACT_D_exp(0.0);
 
-    return R_D_exp(lambda / nu * (1 - sqrt(1 - 2 * nu * nu * x/lambda)));
+    return ACT_D_exp(lambda / nu * (1.0 - sqrt(1.0 - 2.0 * nu * nu * x/lambda)));
 }
