@@ -35,11 +35,11 @@ double dinvtrgamma(double x, double shape1, double shape2, double scale,
 
     /* handle also x == 0 here */
     if (!R_FINITE(x) || x <= 0.0)
-        return R_D__0;
+        return ACT_D__0;
 
     logu = shape2 * (log(scale) - log(x));
 
-    return R_D_exp(log(shape2) + shape1 * logu - exp(logu)
+    return ACT_D_exp(log(shape2) + shape1 * logu - exp(logu)
                    - log(x) - lgammafn(shape1));
 }
 
@@ -57,7 +57,7 @@ double pinvtrgamma(double q, double shape1, double shape2, double scale,
         return R_NaN;;
 
     if (q <= 0)
-        return R_DT_0;
+        return ACT_DT_0;
 
     u = exp(shape2 * (log(scale) - log(q)));
 
@@ -75,8 +75,8 @@ double qinvtrgamma(double p, double shape1, double shape2, double scale,
         scale  <= 0.0)
         return R_NaN;;
 
-    R_Q_P01_boundaries(p, 0, R_PosInf);
-    p = R_D_qIv(p);
+    ACT_Q_P01_boundaries(p, 0, R_PosInf);
+    p = ACT_D_qIv(p);
 
     return scale * R_pow(qgamma(p, shape1, 1.0, !lower_tail, 0),
                          -1.0 / shape2);
@@ -140,5 +140,5 @@ double levinvtrgamma(double limit, double shape1, double shape2, double scale,
 
     return R_pow(scale, order) * gammafn(tmp)
         * pgamma(u, tmp, 1.0, 0, 0) / gammafn(shape1)
-        + R_VG__0(limit, order) * pgamma(u, shape1, 1.0, 1, 0);
+        + ACT_DLIM__0(limit, order) * pgamma(u, shape1, 1.0, 1, 0);
 }
